@@ -26,8 +26,10 @@ modules = [
     "ao3",
     "arcalive",
     "architizer",
+    "arena",
     "artstation",
     "aryion",
+    "audiochan",
     "batoto",
     "bbc",
     "behance",
@@ -39,20 +41,24 @@ modules = [
     "booth",
     "bunkr",
     "catbox",
+    "cfake",
     "chevereto",
     "cien",
     "civitai",
+    "comedywildlifephoto",
     "comick",
     "comicvine",
     "cyberdrop",
     "cyberfile",
     "danbooru",
+    "dandadan",
     "dankefuerslesen",
     "desktopography",
     "deviantart",
     "discord",
     "dynastyscans",
     "e621",
+    "eporner",
     "erome",
     "everia",
     "exhentai",
@@ -62,6 +68,8 @@ modules = [
     "fantia",
     "fapello",
     "fapachi",
+    "fikfap",
+    "fitnakedgirls",
     "flickr",
     "furaffinity",
     "furry34",
@@ -105,6 +113,7 @@ modules = [
     "kemono",
     "khinsider",
     "komikcast",
+    "koofr",
     "leakgallery",
     "lensdump",
     "lexica",
@@ -115,11 +124,13 @@ modules = [
     "lynxchan",
     "madokami",
     "mangadex",
+    "mangafire",
     "mangafox",
     "mangahere",
     "manganelo",
     "mangapark",
     "mangaread",
+    "mangareader",
     "mangataro",
     "mangoxo",
     "misskey",
@@ -137,12 +148,14 @@ modules = [
     "nozomi",
     "nsfwalbum",
     "nudostar",
+    "okporn",
     "paheal",
     "patreon",
     "pexels",
     "philomena",
     "photovogue",
     "picarto",
+    "picazor",
     "pictoa",
     "piczel",
     "pillowfort",
@@ -155,17 +168,18 @@ modules = [
     "poringa",
     "pornhub",
     "pornpics",
+    "pornstarstube",
     "postmill",
     "rawkuma",
     "reactor",
     "readcomiconline",
     "realbooru",
-    "redbust",
     "reddit",
     "redgifs",
     "rule34us",
     "rule34vault",
     "rule34xyz",
+    "s3ndpics",
     "saint",
     "sankaku",
     "sankakucomplex",
@@ -175,7 +189,6 @@ modules = [
     "senmanga",
     "sexcom",
     "shimmie2",
-    "simpcity",
     "simplyhentai",
     "sizebooru",
     "skeb",
@@ -186,6 +199,7 @@ modules = [
     "speakerdeck",
     "steamgriddb",
     "subscribestar",
+    "sxypix",
     "szurubooru",
     "tapas",
     "tcbscans",
@@ -217,11 +231,13 @@ modules = [
     "webmshare",
     "webtoons",
     "weebcentral",
+    "weebdex",
     "weibo",
     "wikiart",
     "wikifeet",
     "wikimedia",
     "xasiat",
+    "xenforo",
     "xfolio",
     "xhamster",
     "xvideos",
@@ -295,7 +311,7 @@ def _list_classes():
 def _modules_internal():
     globals_ = globals()
     for module_name in modules:
-        yield __import__(module_name, globals_, None, (), 1)
+        yield __import__(module_name, globals_, None, None, 1)
 
 
 def _modules_path(path, files):
