@@ -67,7 +67,7 @@ class BehanceExtractor(Extractor):
             tags = [tag["title"] for tag in tags]
         data["tags"] = tags
 
-        data["date"] = text.parse_timestamp(
+        data["date"] = self.parse_timestamp(
             data.get("publishedOn") or data.get("conceived_on") or 0)
 
         if creator := data.get("creator"):
@@ -109,7 +109,7 @@ class BehanceGalleryExtractor(BehanceExtractor):
         imgs = self.get_images(data)
         data["count"] = len(imgs)
 
-        yield Message.Directory, data
+        yield Message.Directory, "", data
         for data["num"], (url, module) in enumerate(imgs, 1):
             data["module"] = module
             data["extension"] = (module.get("extension") or
