@@ -55,8 +55,7 @@ class Furry34Extractor(BooruExtractor):
 
     def _prepare(self, post):
         post.pop("files", None)
-        post["date"] = text.parse_datetime(
-            post["created"], "%Y-%m-%dT%H:%M:%S.%fZ")
+        post["date"] = self.parse_datetime_iso(post["created"])
         post["filename"], _, post["format"] = post["filename"].rpartition(".")
         if "tags" in post:
             post["tags"] = [t["value"] for t in post["tags"]]
@@ -98,7 +97,7 @@ class Furry34Extractor(BooruExtractor):
 class Furry34PostExtractor(Furry34Extractor):
     subcategory = "post"
     archive_fmt = "{id}"
-    pattern = BASE_PATTERN + r"/post/(\d+)"
+    pattern = rf"{BASE_PATTERN}/post/(\d+)"
     example = "https://furry34.com/post/12345"
 
     def posts(self):
@@ -109,7 +108,7 @@ class Furry34PlaylistExtractor(Furry34Extractor):
     subcategory = "playlist"
     directory_fmt = ("{category}", "{playlist_id}")
     archive_fmt = "p_{playlist_id}_{id}"
-    pattern = BASE_PATTERN + r"/playlists/view/(\d+)"
+    pattern = rf"{BASE_PATTERN}/playlists/view/(\d+)"
     example = "https://furry34.com/playlists/view/12345"
 
     def metadata(self):
@@ -124,7 +123,7 @@ class Furry34TagExtractor(Furry34Extractor):
     subcategory = "tag"
     directory_fmt = ("{category}", "{search_tags}")
     archive_fmt = "t_{search_tags}_{id}"
-    pattern = BASE_PATTERN + r"/(?:([^/?#]+))?(?:/?\?([^#]+))?(?:$|#)"
+    pattern = rf"{BASE_PATTERN}/(?:([^/?#]+))?(?:/?\?([^#]+))?(?:$|#)"
     example = "https://furry34.com/TAG"
 
     def _init(self):
