@@ -96,7 +96,7 @@ class GelbooruV02Extractor(booru.BooruExtractor):
         params["pid"] = self.page_start * self.per_page
 
         data = {}
-        find_ids = util.re(r"\sid=\"p(\d+)").findall
+        find_ids = text.re(r"\sid=\"p(\d+)").findall
 
         while True:
             page = self.request(url, params=params).text
@@ -122,7 +122,7 @@ class GelbooruV02Extractor(booru.BooruExtractor):
 
     def _prepare(self, post):
         post["tags"] = post["tags"].strip()
-        post["date"] = text.parse_datetime(
+        post["date"] = self.parse_datetime(
             post["created_at"], "%a %b %d %H:%M:%S %z %Y")
 
     def _html(self, post):
@@ -136,7 +136,7 @@ class GelbooruV02Extractor(booru.BooruExtractor):
             return
 
         tags = collections.defaultdict(list)
-        pattern = util.re(r"(?s)tag-type-([^\"' ]+).*?[?;]tags=([^\"'&]+)")
+        pattern = text.re(r"(?s)tag-type-([^\"' ]+).*?[?;]tags=([^\"'&]+)")
         for tag_type, tag_name in pattern.findall(tag_container):
             tags[tag_type].append(text.unescape(text.unquote(tag_name)))
         for key, value in tags.items():
@@ -190,7 +190,7 @@ class GelbooruV02TagExtractor(GelbooruV02Extractor):
     subcategory = "tag"
     directory_fmt = ("{category}", "{search_tags}")
     archive_fmt = "t_{search_tags}_{id}"
-    pattern = BASE_PATTERN + r"/index\.php\?page=post&s=list&tags=([^&#]*)"
+    pattern = rf"{BASE_PATTERN}/index\.php\?page=post&s=list&tags=([^&#]*)"
     example = "https://safebooru.org/index.php?page=post&s=list&tags=TAG"
 
     def posts(self):
@@ -206,7 +206,7 @@ class GelbooruV02PoolExtractor(GelbooruV02Extractor):
     subcategory = "pool"
     directory_fmt = ("{category}", "pool", "{pool}")
     archive_fmt = "p_{pool}_{id}"
-    pattern = BASE_PATTERN + r"/index\.php\?page=pool&s=show&id=(\d+)"
+    pattern = rf"{BASE_PATTERN}/index\.php\?page=pool&s=show&id=(\d+)"
     example = "https://safebooru.org/index.php?page=pool&s=show&id=12345"
 
     def __init__(self, match):
@@ -257,7 +257,7 @@ class GelbooruV02FavoriteExtractor(GelbooruV02Extractor):
     directory_fmt = ("{category}", "favorites", "{favorite_id}")
     archive_fmt = "f_{favorite_id}_{id}"
     per_page = 50
-    pattern = BASE_PATTERN + r"/index\.php\?page=favorites&s=view&id=(\d+)"
+    pattern = rf"{BASE_PATTERN}/index\.php\?page=favorites&s=view&id=(\d+)"
     example = "https://safebooru.org/index.php?page=favorites&s=view&id=12345"
 
     def metadata(self):
@@ -275,7 +275,7 @@ class GelbooruV02FavoriteExtractor(GelbooruV02Extractor):
 class GelbooruV02PostExtractor(GelbooruV02Extractor):
     subcategory = "post"
     archive_fmt = "{id}"
-    pattern = BASE_PATTERN + r"/index\.php\?page=post&s=view&id=(\d+)"
+    pattern = rf"{BASE_PATTERN}/index\.php\?page=post&s=view&id=(\d+)"
     example = "https://safebooru.org/index.php?page=post&s=view&id=12345"
 
     def posts(self):
