@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright 2021 Seonghyeon Cho
-# Copyright 2022-2033 Mike Fährmann
+# Copyright 2022-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -16,23 +16,23 @@ BASE_PATTERN = (r"(?:https?://)?comic\.naver\.com"
                 r"/(webtoon|challenge|bestChallenge)")
 
 
-class NaverwebtoonBase():
-    """Base class for naver webtoon extractors"""
-    category = "naverwebtoon"
+class NaverWebtoonBase():
+    """Base class for comic.naver.com extractors"""
+    category = "naver-webtoon"
     root = "https://comic.naver.com"
 
 
-class NaverwebtoonEpisodeExtractor(NaverwebtoonBase, GalleryExtractor):
+class NaverWebtoonEpisodeExtractor(NaverWebtoonBase, GalleryExtractor):
     subcategory = "episode"
     directory_fmt = ("{category}", "{comic}")
     filename_fmt = "{episode:>03}-{num:>02}.{extension}"
     archive_fmt = "{title_id}_{episode}_{num}"
-    pattern = BASE_PATTERN + r"/detail(?:\.nhn)?\?([^#]+)"
+    pattern = rf"{BASE_PATTERN}/detail(?:\.nhn)?\?([^#]+)"
     example = "https://comic.naver.com/webtoon/detail?titleId=12345&no=1"
 
     def __init__(self, match):
         path, query = match.groups()
-        url = "{}/{}/detail?{}".format(self.root, path, query)
+        url = f"{self.root}/{path}/detail?{query}"
         GalleryExtractor.__init__(self, match, url)
 
         query = text.parse_query(query)
@@ -46,7 +46,7 @@ class NaverwebtoonEpisodeExtractor(NaverwebtoonBase, GalleryExtractor):
             "episode" : self.episode,
             "comic"   : extr('titleName: "', '"'),
             "tags"    : [t.strip() for t in text.extract_iter(
-                extr("tagList: [", "}],"), '"tagName":"', '"')],
+                extr("tagList: [", "],"), '"tagName":"', '"')],
             "title"   : extr('"subtitle":"', '"'),
             "author"  : [a.strip() for a in text.extract_iter(
                 extr('"writers":[', ']'), '"name":"', '"')],
@@ -54,8 +54,7 @@ class NaverwebtoonEpisodeExtractor(NaverwebtoonBase, GalleryExtractor):
                 extr('"painters":[', ']'), '"name":"', '"')]
         }
 
-    @staticmethod
-    def images(page):
+    def images(self, page):
         view_area = text.extr(page, 'id="comic_view_area"', '</div>')
         return [
             (url, None)
@@ -64,10 +63,10 @@ class NaverwebtoonEpisodeExtractor(NaverwebtoonBase, GalleryExtractor):
         ]
 
 
-class NaverwebtoonComicExtractor(NaverwebtoonBase, Extractor):
+class NaverWebtoonComicExtractor(NaverWebtoonBase, Extractor):
     subcategory = "comic"
     categorytransfer = True
-    pattern = BASE_PATTERN + r"/list(?:\.nhn)?\?([^#]+)"
+    pattern = rf"{BASE_PATTERN}/list(?:\.nhn)?\?([^#]+)"
     example = "https://comic.naver.com/webtoon/list?titleId=12345"
 
     def __init__(self, match):
@@ -79,9 +78,6 @@ class NaverwebtoonComicExtractor(NaverwebtoonBase, Extractor):
         self.sort = query.get("sort", "ASC")
 
     def items(self):
-        base = "{}/{}/detail?titleId={}&no=".format(
-            self.root, self.path, self.title_id)
-
         url = self.root + "/api/article/list"
         headers = {
             "Accept": "application/json, text/plain, */*",
@@ -93,10 +89,13 @@ class NaverwebtoonComicExtractor(NaverwebtoonBase, Extractor):
         }
 
         while True:
-            data = self.request(url, headers=headers, params=params).json()
+            data = self.request_json(url, headers=headers, params=params)
+
+            path = data["webtoonLevelCode"].lower().replace("_c", "C", 1)
+            base = f"{self.root}/{path}/detail?titleId={data['titleId']}&no="
 
             for article in data["articleList"]:
-                article["_extractor"] = NaverwebtoonEpisodeExtractor
+                article["_extractor"] = NaverWebtoonEpisodeExtractor
                 yield Message.Queue, base + str(article["no"]), article
 
             params["page"] = data["pageInfo"]["nextPage"]
