@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2019-2023 Mike Fährmann
+# Copyright 2019-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -9,7 +9,7 @@
 """Extractors for https://nozomi.la/"""
 
 from .common import Extractor, Message
-from .. import text
+from .. import text, dt
 
 
 def decode_nozomi(n):
@@ -32,8 +32,8 @@ class NozomiExtractor(Extractor):
         data = self.metadata()
 
         for post_id in map(str, self.posts()):
-            url = "https://j.{}/post/{}/{}/{}.json".format(
-                self.domain, post_id[-1], post_id[-3:-1], post_id)
+            url = (f"https://j.{self.domain}/post"
+                   f"/{post_id[-1]}/{post_id[-3:-1]}/{post_id}.json")
             response = self.request(url, fatal=False)
 
             if response.status_code >= 400:
@@ -49,10 +49,9 @@ class NozomiExtractor(Extractor):
             post["character"] = self._list(post.get("character"))
 
             try:
-                post["date"] = text.parse_datetime(
-                    post["date"] + ":00", "%Y-%m-%d %H:%M:%S%z")
+                post["date"] = dt.parse_iso(post["date"] + ":00")
             except Exception:
-                post["date"] = None
+                post["date"] = dt.NONE
 
             post.update(data)
 
@@ -61,7 +60,7 @@ class NozomiExtractor(Extractor):
                 if key in post:
                     del post[key]
 
-            yield Message.Directory, post
+            yield Message.Directory, "", post
             for post["num"], image in enumerate(images, 1):
                 post["filename"] = post["dataid"] = did = image["dataid"]
                 post["is_video"] = video = \
@@ -77,8 +76,8 @@ class NozomiExtractor(Extractor):
                     ext = "webp"
 
                 post["extension"] = ext
-                post["url"] = url = "https://{}.{}/{}/{}/{}.{}".format(
-                    subdomain, self.domain, did[-1], did[-3:-1], did, ext)
+                post["url"] = url = (f"https://{subdomain}.{self.domain}"
+                                     f"/{did[-1]}/{did[-3:-1]}/{did}.{ext}")
                 yield Message.Url, url, post
 
     def posts(self):
@@ -86,7 +85,7 @@ class NozomiExtractor(Extractor):
         offset = (text.parse_int(self.pnum, 1) - 1) * 256
 
         while True:
-            headers = {"Range": "bytes={}-{}".format(offset, offset+255)}
+            headers = {"Range": f"bytes={offset}-{offset + 255}"}
             response = self.request(url, headers=headers)
             yield from decode_nozomi(response.content)
 
@@ -98,8 +97,7 @@ class NozomiExtractor(Extractor):
     def metadata(self):
         return {}
 
-    @staticmethod
-    def _list(src):
+    def _list(self, src):
         return [x["tagname_display"] for x in src] if src else ()
 
 
@@ -111,7 +109,7 @@ class NozomiPostExtractor(NozomiExtractor):
 
     def __init__(self, match):
         NozomiExtractor.__init__(self, match)
-        self.post_id = match.group(1)
+        self.post_id = match[1]
 
     def posts(self):
         return (self.post_id,)
@@ -127,7 +125,7 @@ class NozomiIndexExtractor(NozomiExtractor):
     def __init__(self, match):
         NozomiExtractor.__init__(self, match)
         index, self.pnum = match.groups()
-        self.nozomi = "/{}.nozomi".format(index or "index")
+        self.nozomi = f"/{index or 'index'}.nozomi"
 
 
 class NozomiTagExtractor(NozomiExtractor):
@@ -142,7 +140,7 @@ class NozomiTagExtractor(NozomiExtractor):
         NozomiExtractor.__init__(self, match)
         tags, self.pnum = match.groups()
         self.tags = text.unquote(tags)
-        self.nozomi = "/nozomi/{}.nozomi".format(self.tags)
+        self.nozomi = f"/nozomi/{self.tags}.nozomi"
 
     def metadata(self):
         return {"search_tags": self.tags}
@@ -158,7 +156,7 @@ class NozomiSearchExtractor(NozomiExtractor):
 
     def __init__(self, match):
         NozomiExtractor.__init__(self, match)
-        self.tags = text.unquote(match.group(1)).split()
+        self.tags = text.unquote(match[1]).split()
 
     def metadata(self):
         return {"search_tags": self.tags}
@@ -169,12 +167,12 @@ class NozomiSearchExtractor(NozomiExtractor):
         negative = []
 
         def nozomi(path):
-            url = "https://j.{}/{}.nozomi".format(self.domain, path)
+            url = f"https://j.{self.domain}/{path}.nozomi"
             return decode_nozomi(self.request(url).content)
 
         for tag in self.tags:
             (negative if tag[0] == "-" else positive).append(
-                tag.replace("/", ""))
+                text.quote(tag.replace("/", "")))
 
         for tag in positive:
             ids = nozomi("nozomi/" + tag)
