@@ -11,6 +11,8 @@
 from .common import Extractor, Message
 from .. import text
 
+BASE_PATTERN = r"(?:https?://)?(?:www\.)?piczel\.tv"
+
 
 class PiczelExtractor(Extractor):
     """Base class for piczel extractors"""
@@ -19,18 +21,18 @@ class PiczelExtractor(Extractor):
     filename_fmt = "{category}_{id}_{title}_{num:>02}.{extension}"
     archive_fmt = "{id}_{num}"
     root = "https://piczel.tv"
-    api_root = root
+    root_api = root
 
     def items(self):
         for post in self.posts():
             post["tags"] = [t["title"] for t in post["tags"] if t["title"]]
-            post["date"] = text.parse_datetime(
-                post["created_at"], "%Y-%m-%dT%H:%M:%S.%f%z")
+            post["date"] = self.parse_datetime_iso(post["created_at"])
 
             if post["multi"]:
                 images = post["images"]
                 del post["images"]
-                yield Message.Directory, post
+                post["count"] = len(images)
+                yield Message.Directory, "", post
                 for post["num"], image in enumerate(images):
                     if "id" in image:
                         del image["id"]
@@ -39,7 +41,8 @@ class PiczelExtractor(Extractor):
                     yield Message.Url, url, text.nameext_from_url(url, post)
 
             else:
-                yield Message.Directory, post
+                post["count"] = 1
+                yield Message.Directory, "", post
                 post["num"] = 0
                 url = post["image"]["url"]
                 yield Message.Url, url, text.nameext_from_url(url, post)
@@ -47,35 +50,27 @@ class PiczelExtractor(Extractor):
     def posts(self):
         """Return an iterable with all relevant post objects"""
 
-    def _pagination(self, url, folder_id=None):
-        params = {
-            "from_id"  : None,
-            "folder_id": folder_id,
-        }
+    def _pagination(self, url, pnum=1):
+        params = {"page": pnum}
 
         while True:
-            data = self.request(url, params=params).json()
-            if not data:
-                return
-            params["from_id"] = data[-1]["id"]
+            data = self.request_json(url, params=params)
 
-            for post in data:
-                if not folder_id or folder_id == post["folder_id"]:
-                    yield post
+            yield from data["data"]
+
+            params["page"] = data["meta"]["next_page"]
+            if not params["page"]:
+                return
 
 
 class PiczelUserExtractor(PiczelExtractor):
     """Extractor for all images from a user's gallery"""
     subcategory = "user"
-    pattern = r"(?:https?://)?(?:www\.)?piczel\.tv/gallery/([^/?#]+)/?$"
+    pattern = rf"{BASE_PATTERN}/gallery/([^/?#]+)/?$"
     example = "https://piczel.tv/gallery/USER"
 
-    def __init__(self, match):
-        PiczelExtractor.__init__(self, match)
-        self.user = match.group(1)
-
     def posts(self):
-        url = "{}/api/users/{}/gallery".format(self.api_root, self.user)
+        url = f"{self.root_api}/api/users/{self.groups[0]}/gallery"
         return self._pagination(url)
 
 
@@ -84,29 +79,20 @@ class PiczelFolderExtractor(PiczelExtractor):
     subcategory = "folder"
     directory_fmt = ("{category}", "{user[username]}", "{folder[name]}")
     archive_fmt = "f{folder[id]}_{id}_{num}"
-    pattern = (r"(?:https?://)?(?:www\.)?piczel\.tv"
-               r"/gallery/(?!image)([^/?#]+)/(\d+)")
+    pattern = rf"{BASE_PATTERN}/gallery/(?!image/)[^/?#]+/(\d+)"
     example = "https://piczel.tv/gallery/USER/12345"
 
-    def __init__(self, match):
-        PiczelExtractor.__init__(self, match)
-        self.user, self.folder_id = match.groups()
-
     def posts(self):
-        url = "{}/api/users/{}/gallery".format(self.api_root, self.user)
-        return self._pagination(url, int(self.folder_id))
+        url = f"{self.root_api}/api/gallery/folder/{self.groups[0]}"
+        return self._pagination(url)
 
 
 class PiczelImageExtractor(PiczelExtractor):
     """Extractor for individual images"""
     subcategory = "image"
-    pattern = r"(?:https?://)?(?:www\.)?piczel\.tv/gallery/image/(\d+)"
+    pattern = rf"{BASE_PATTERN}/gallery/image/(\d+)"
     example = "https://piczel.tv/gallery/image/12345"
 
-    def __init__(self, match):
-        PiczelExtractor.__init__(self, match)
-        self.image_id = match.group(1)
-
     def posts(self):
-        url = "{}/api/gallery/{}".format(self.api_root, self.image_id)
-        return (self.request(url).json(),)
+        url = f"{self.root_api}/api/gallery/{self.groups[0]}"
+        return (self.request_json(url),)
