@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2023-2024 Mike Fährmann
+# Copyright 2023-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,35 +21,30 @@ class PixeldrainExtractor(Extractor):
     archive_fmt = "{id}"
 
     def _init(self):
-        api_key = self.config("api-key")
-        if api_key:
+        if api_key := self.config("api-key"):
             self.session.auth = util.HTTPBasicAuth("", api_key)
 
-    def parse_datetime(self, date_string):
-        return text.parse_datetime(
-            date_string, "%Y-%m-%dT%H:%M:%S.%fZ")
-
 
 class PixeldrainFileExtractor(PixeldrainExtractor):
     """Extractor for pixeldrain files"""
     subcategory = "file"
     filename_fmt = "{filename[:230]} ({id}).{extension}"
-    pattern = BASE_PATTERN + r"/(?:u|api/file)/(\w+)"
+    pattern = rf"{BASE_PATTERN}/(?:u|api/file)/(\w+)"
     example = "https://pixeldrain.com/u/abcdefgh"
 
     def __init__(self, match):
         Extractor.__init__(self, match)
-        self.file_id = match.group(1)
+        self.file_id = match[1]
 
     def items(self):
-        url = "{}/api/file/{}".format(self.root, self.file_id)
-        file = self.request(url + "/info").json()
+        url = f"{self.root}/api/file/{self.file_id}"
+        file = self.request_json(url + "/info")
 
         file["url"] = url + "?download"
-        file["date"] = self.parse_datetime(file["date_upload"])
+        file["date"] = self.parse_datetime_iso(file["date_upload"])
 
         text.nameext_from_url(file["name"], file)
-        yield Message.Directory, file
+        yield Message.Directory, "", file
         yield Message.Url, file["url"], file
 
 
@@ -59,21 +54,21 @@ class PixeldrainAlbumExtractor(PixeldrainExtractor):
     directory_fmt = ("{category}",
                      "{album[date]:%Y-%m-%d} {album[title]} ({album[id]})")
     filename_fmt = "{num:>03} {filename[:230]} ({id}).{extension}"
-    pattern = BASE_PATTERN + r"/(?:l|api/list)/(\w+)(?:#item=(\d+))?"
+    pattern = rf"{BASE_PATTERN}/(?:l|api/list)/(\w+)(?:#item=(\d+))?"
     example = "https://pixeldrain.com/l/abcdefgh"
 
     def __init__(self, match):
         Extractor.__init__(self, match)
-        self.album_id = match.group(1)
-        self.file_index = match.group(2)
+        self.album_id = match[1]
+        self.file_index = match[2]
 
     def items(self):
-        url = "{}/api/list/{}".format(self.root, self.album_id)
-        album = self.request(url).json()
+        url = f"{self.root}/api/list/{self.album_id}"
+        album = self.request_json(url)
 
         files = album["files"]
         album["count"] = album["file_count"]
-        album["date"] = self.parse_datetime(album["date_created"])
+        album["date"] = self.parse_datetime_iso(album["date_created"])
 
         if self.file_index:
             idx = text.parse_int(self.file_index)
@@ -87,13 +82,12 @@ class PixeldrainAlbumExtractor(PixeldrainExtractor):
         del album["files"]
         del album["file_count"]
 
-        yield Message.Directory, {"album": album}
+        yield Message.Directory, "", {"album": album}
         for num, file in enumerate(files, idx+1):
             file["album"] = album
             file["num"] = num
-            file["url"] = url = "{}/api/file/{}?download".format(
-                self.root, file["id"])
-            file["date"] = self.parse_datetime(file["date_upload"])
+            file["url"] = url = f"{self.root}/api/file/{file['id']}?download"
+            file["date"] = self.parse_datetime_iso(file["date_upload"])
             text.nameext_from_url(file["name"], file)
             yield Message.Url, url, file
 
@@ -103,7 +97,7 @@ class PixeldrainFolderExtractor(PixeldrainExtractor):
     subcategory = "folder"
     filename_fmt = "{filename[:230]}.{extension}"
     archive_fmt = "{path}_{num}"
-    pattern = BASE_PATTERN + r"/(?:d|api/filesystem)/([^?]+)"
+    pattern = rf"{BASE_PATTERN}/(?:d|api/filesystem)/([^?]+)"
     example = "https://pixeldrain.com/d/abcdefgh"
 
     def metadata(self, data):
@@ -114,14 +108,14 @@ class PixeldrainFolderExtractor(PixeldrainExtractor):
             "mime_type"  : data["file_type"],
             "size"       : data["file_size"],
             "hash_sha256": data["sha256_sum"],
-            "date"       : self.parse_datetime(data["created"]),
+            "date"       : self.parse_datetime_iso(data["created"]),
         }
 
     def items(self):
         recursive = self.config("recursive")
 
-        url = "{}/api/filesystem/{}".format(self.root, self.groups[0])
-        stat = self.request(url + "?stat").json()
+        url = f"{self.root}/api/filesystem/{self.groups[0]}"
+        stat = self.request_json(url + "?stat")
 
         paths = stat["path"]
         path = paths[stat["base_index"]]
@@ -137,15 +131,14 @@ class PixeldrainFolderExtractor(PixeldrainExtractor):
         folder = self.metadata(path)
         folder["id"] = paths[0]["id"]
 
-        yield Message.Directory, folder
+        yield Message.Directory, "", folder
 
         num = 0
         for child in children:
             if child["type"] == "file":
                 num += 1
-                url = "{}/api/filesystem{}?attach".format(
-                    self.root, child["path"])
-                share_url = "{}/d{}".format(self.root, child["path"])
+                url = f"{self.root}/api/filesystem{child['path']}?attach"
+                share_url = f"{self.root}/d{child['path']}"
                 data = self.metadata(child)
                 data.update({
                     "id"       : folder["id"],
@@ -159,7 +152,7 @@ class PixeldrainFolderExtractor(PixeldrainExtractor):
 
             elif child["type"] == "dir":
                 if recursive:
-                    url = "{}/d{}".format(self.root, child["path"])
+                    url = f"{self.root}/d{child['path']}"
                     child["_extractor"] = PixeldrainFolderExtractor
                     yield Message.Queue, url, child
 
