@@ -9,7 +9,7 @@
 """Extractors for https://rule34.us/"""
 
 from .booru import BooruExtractor
-from .. import text, util
+from .. import text
 import collections
 
 
@@ -19,7 +19,7 @@ class Rule34usExtractor(BooruExtractor):
     per_page = 42
 
     def _init(self):
-        self._find_tags = util.re(
+        self._find_tags = text.re(
             r'<li class="([^-"]+)-tag"[^>]*><a href="[^;"]+;q=([^"]+)').findall
 
     def _parse_post(self, post_id):
@@ -57,7 +57,7 @@ class Rule34usTagExtractor(Rule34usExtractor):
     subcategory = "tag"
     directory_fmt = ("{category}", "{search_tags}")
     archive_fmt = "t_{search_tags}_{id}"
-    pattern = r"(?:https?://)?rule34\.us/index\.php\?r=posts/index&q=([^&#]+)"
+    pattern = r"(?:https?://)?rule34\.us/index\.php\?r=posts/index&q=([^&#]*)"
     example = "https://rule34.us/index.php?r=posts/index&q=TAG"
 
     def __init__(self, match):
