@@ -32,7 +32,7 @@ BASE_PATTERN = UrlshortenerExtractor.update({
 class UrlshortenerLinkExtractor(UrlshortenerExtractor):
     """Extractor for general-purpose URL shorteners"""
     subcategory = "link"
-    pattern = BASE_PATTERN + r"(/[^/?#]+)"
+    pattern = rf"{BASE_PATTERN}(/[^/?#]+)"
     example = "https://bit.ly/abcde"
 
     def items(self):
@@ -40,5 +40,5 @@ class UrlshortenerLinkExtractor(UrlshortenerExtractor):
         location = self.request_location(
             url, headers=self.config_instance("headers"), notfound="URL")
         if not location:
-            raise exception.StopExtraction("Unable to resolve short URL")
+            raise exception.AbortExtraction("Unable to resolve short URL")
         yield Message.Queue, location, {}
