@@ -15,7 +15,7 @@ import datetime
 import tempfile
 
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-from gallery_dl import formatter, text, util, config  # noqa E402
+from gallery_dl import formatter, text, dt, util, config  # noqa E402
 
 try:
     import jinja2
@@ -44,6 +44,11 @@ class TestFormatter(unittest.TestCase):
         "s": " \n\r\tSPACE    ",
         "S": " \n\r\tS  P         A\tC\nE    ",
         "h": "<p>foo </p> &amp; bar <p> </p>",
+        "H": """<p>
+  <a href="http://www.example.com">Lorem ipsum dolor sit amet</a>.
+  Duis aute irure <a href="http://blog.example.org/lorem?foo=bar">
+  http://blog.example.org</a>.
+</p>""",
         "u": "&#x27;&lt; / &gt;&#x27;",
         "t": 1262304000,
         "ds": "2010-01-01T01:00:00+01:00",
@@ -72,9 +77,13 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{h!H}", "foo & bar")
         self._run_test("{u!H}", "'< / >'")
         self._run_test("{n!H}", "")
+        self._run_test("{h!R}", [])
+        self._run_test("{H!R}", ["http://www.example.com",
+                                 "http://blog.example.org/lorem?foo=bar",
+                                 "http://blog.example.org"])
         self._run_test("{a!s}", self.kwdict["a"])
-        self._run_test("{a!r}", "'" + self.kwdict["a"] + "'")
-        self._run_test("{a!a}", "'" + self.kwdict["a"] + "'")
+        self._run_test("{a!r}", f"'{self.kwdict['a']}'")
+        self._run_test("{a!a}", f"'{self.kwdict['a']}'")
         self._run_test("{b!a}", "'\\xe4\\xf6\\xfc'")
         self._run_test("{a!S}", self.kwdict["a"])
         self._run_test("{l!S}", "a, b, c")
@@ -139,13 +148,13 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{missing}"     , replacement, default)
         self._run_test("{missing.attr}", replacement, default)
         self._run_test("{missing[key]}", replacement, default)
-        self._run_test("{missing:?a//}", "a" + default, default)
+        self._run_test("{missing:?a//}", f"a{default}", default)
 
     def test_fmt_func(self):
         self._run_test("{t}" , self.kwdict["t"] , None, int)
         self._run_test("{t}" , self.kwdict["t"] , None, util.identity)
         self._run_test("{dt}", self.kwdict["dt"], None, util.identity)
-        self._run_test("{ds}", self.kwdict["dt"], None, text.parse_datetime)
+        self._run_test("{ds}", self.kwdict["dt"], None, dt.parse_iso)
         self._run_test("{ds:D%Y-%m-%dT%H:%M:%S%z}", self.kwdict["dt"],
                        None, util.identity)
 
@@ -169,6 +178,11 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{l[0]}" , "a")
         self._run_test("{a[6]}" , "w")
 
+    def test_indexing_negative(self):
+        self._run_test("{l[-1]}" , "c")
+        self._run_test("{a[-7]}" , "o")
+        self._run_test("{a[-0]}" , "h")  # same as a[0]
+
     def test_dict_access(self):
         self._run_test("{d[a]}"  , "foo")
         self._run_test("{d['a']}", "foo")
@@ -234,6 +248,19 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{a:L50/foo/>51}", "foo")
         self._run_test("{a:Lab/foo/}", "foo")
 
+    def test_specifier_maxlen_bytes(self):
+        v = self.kwdict["a"]
+        self._run_test("{a:Lb5/foo/}" , "foo")
+        self._run_test("{a:Lb50/foo/}", v)
+        self._run_test("{a:Lb50/foo/>50}", " " * 39 + v)
+        self._run_test("{a:Lb50/foo/>51}", "foo")
+        self._run_test("{a:Lbab/foo/}", "foo")
+
+        v = self.kwdict["j"]
+        self._run_test("{j:Lb5/foo/}" , "foo")
+        self._run_test("{j:Lb50/foo/}", v)
+        self._run_test("{j:Lbab/foo/}", "foo")
+
     def test_specifier_join(self):
         self._run_test("{l:J}"       , "abc")
         self._run_test("{l:J,}"      , "a,b,c")
@@ -257,8 +284,8 @@ class TestFormatter(unittest.TestCase):
 
     def test_specifier_datetime(self):
         self._run_test("{ds:D%Y-%m-%dT%H:%M:%S%z}", "2010-01-01 00:00:00")
-        self._run_test("{ds:D%Y}", "2010-01-01T01:00:00+01:00")
-        self._run_test("{l:D%Y}", "None")
+        self._run_test("{ds:D%Y}", "[Invalid DateTime]")
+        self._run_test("{l2:D%Y}", "[Invalid DateTime]")
 
     def test_specifier_offset(self):
         self._run_test("{dt:O 01:00}", "2010-01-01 01:00:00")
@@ -318,6 +345,17 @@ class TestFormatter(unittest.TestCase):
         with self.assertRaises(ValueError):
             self._run_test("{a:Xfoo/ */}", "hello wo *")
 
+    def test_specifier_limit_bytes(self):
+        self._run_test("{a:Xb20/ */}", "hElLo wOrLd")
+        self._run_test("{a:Xb10/ */}", "hElLo wO *")
+
+        self._run_test("{j:Xb50/〜/}", "げんそうきょう")
+        self._run_test("{j:Xb20/〜/}", "げんそうき〜")
+        self._run_test("{j:Xb20/ */}", "げんそうきょ *")
+
+        with self.assertRaises(ValueError):
+            self._run_test("{a:Xbfoo/ */}", "hello wo *")
+
     def test_specifier_map(self):
         self._run_test("{L:Mname/}" ,
                        "['John Doe', 'Jane Smith', 'Max Mustermann']")
@@ -331,6 +369,15 @@ class TestFormatter(unittest.TestCase):
         with self.assertRaises(ValueError):
             self._run_test("{t:Mname", "")
 
+    def test_specifier_identity(self):
+        self._run_test("{a:I}", self.kwdict["a"])
+        self._run_test("{i:I}", self.kwdict["i"])
+        self._run_test("{dt:I}", self.kwdict["dt"])
+
+        self._run_test("{t!D:I}", self.kwdict["dt"])
+        self._run_test("{t!D:I/O+01:30}", self.kwdict["dt"])
+        self._run_test("{i:A+1/I}", self.kwdict["i"]+1)
+
     def test_chain_special(self):
         # multiple replacements
         self._run_test("{a:Rh/C/RE/e/RL/l/}", "Cello wOrld")
@@ -444,11 +491,11 @@ class TestFormatter(unittest.TestCase):
 
             with open(path1, "w") as fp:
                 fp.write("{a}")
-            fmt1 = formatter.parse("\fT " + path1)
+            fmt1 = formatter.parse(f"\fT {path1}")
 
             with open(path2, "w") as fp:
                 fp.write("{a!u:Rh/C/}\nFooBar")
-            fmt2 = formatter.parse("\fT " + path2)
+            fmt2 = formatter.parse(f"\fT {path2}")
 
         self.assertEqual(fmt1.format_map(self.kwdict), self.kwdict["a"])
         self.assertEqual(fmt2.format_map(self.kwdict), "HELLO WORLD\nFooBar")
@@ -458,15 +505,18 @@ class TestFormatter(unittest.TestCase):
 
     def test_expression(self):
         self._run_test("\fE a", self.kwdict["a"])
-        self._run_test("\fE name * 2 + ' ' + a", "{}{} {}".format(
-            self.kwdict["name"], self.kwdict["name"], self.kwdict["a"]))
+        self._run_test(
+            "\fE name * 2 + ' ' + a",
+            f"{self.kwdict['name']}{self.kwdict['name']} {self.kwdict['a']}")
 
     def test_fstring(self):
         self._run_test("\fF {a}", self.kwdict["a"])
-        self._run_test("\fF {name}{name} {a}", "{}{} {}".format(
-            self.kwdict["name"], self.kwdict["name"], self.kwdict["a"]))
-        self._run_test("\fF foo-'\"{a.upper()}\"'-bar",
-                       """foo-'"{}"'-bar""".format(self.kwdict["a"].upper()))
+        self._run_test(
+            "\fF {name}{name} {a}",
+            f"{self.kwdict['name']}{self.kwdict['name']} {self.kwdict['a']}")
+        self._run_test(
+            "\fF foo-'\"{a.upper()}\"'-bar",
+            f"""foo-'"{self.kwdict['a'].upper()}"'-bar""")
 
     def test_template_fstring(self):
         with tempfile.TemporaryDirectory() as tmpdirname:
@@ -475,15 +525,15 @@ class TestFormatter(unittest.TestCase):
 
             with open(path1, "w") as fp:
                 fp.write("{a}")
-            fmt1 = formatter.parse("\fTF " + path1)
+            fmt1 = formatter.parse(f"\fTF {path1}")
 
             with open(path2, "w") as fp:
                 fp.write("foo-'\"{a.upper()}\"'-bar")
-            fmt2 = formatter.parse("\fTF " + path2)
+            fmt2 = formatter.parse(f"\fTF {path2}")
 
         self.assertEqual(fmt1.format_map(self.kwdict), self.kwdict["a"])
         self.assertEqual(fmt2.format_map(self.kwdict),
-                         """foo-'"{}"'-bar""".format(self.kwdict["a"].upper()))
+                         f"""foo-'"{self.kwdict['a'].upper()}"'-bar""")
 
         with self.assertRaises(OSError):
             formatter.parse("\fTF /")
@@ -493,10 +543,12 @@ class TestFormatter(unittest.TestCase):
         formatter.JinjaFormatter.env = None
 
         self._run_test("\fJ {{a}}", self.kwdict["a"])
-        self._run_test("\fJ {{name}}{{name}} {{a}}", "{}{} {}".format(
-            self.kwdict["name"], self.kwdict["name"], self.kwdict["a"]))
-        self._run_test("\fJ foo-'\"{{a | upper}}\"'-bar",
-                       """foo-'"{}"'-bar""".format(self.kwdict["a"].upper()))
+        self._run_test(
+            "\fJ {{name}}{{name}} {{a}}",
+            f"{self.kwdict['name']}{self.kwdict['name']} {self.kwdict['a']}")
+        self._run_test(
+            "\fJ foo-'\"{{a | upper}}\"'-bar",
+            f"""foo-'"{self.kwdict['a'].upper()}"'-bar""")
 
     @unittest.skipIf(jinja2 is None, "no jinja2")
     def test_template_jinja(self):
@@ -508,15 +560,15 @@ class TestFormatter(unittest.TestCase):
 
             with open(path1, "w") as fp:
                 fp.write("{{a}}")
-            fmt1 = formatter.parse("\fTJ " + path1)
+            fmt1 = formatter.parse(f"\fTJ {path1}")
 
             with open(path2, "w") as fp:
                 fp.write("foo-'\"{{a | upper}}\"'-bar")
-            fmt2 = formatter.parse("\fTJ " + path2)
+            fmt2 = formatter.parse(f"\fTJ {path2}")
 
         self.assertEqual(fmt1.format_map(self.kwdict), self.kwdict["a"])
         self.assertEqual(fmt2.format_map(self.kwdict),
-                         """foo-'"{}"'-bar""".format(self.kwdict["a"].upper()))
+                         f"""foo-'"{self.kwdict['a'].upper()}"'-bar""")
 
         with self.assertRaises(OSError):
             formatter.parse("\fTJ /")
@@ -562,7 +614,7 @@ Present Time is ((( dt | dt_fmt("%H:%M:%S") )))
 Hello ((( s | sanitize_whitespace ))).
 I hope there is enough "(((S|sanitize_whitespace)))" for you.
 """)
-            fmt = formatter.parse("\fTJ " + path_template)
+            fmt = formatter.parse(f"\fTJ {path_template}")
 
         self.assertEqual(fmt.format_map(self.kwdict), """\
 Present Day  is January 01, 2010
@@ -585,10 +637,11 @@ def gentext(kwdict):
 def lengths(kwdict):
     a = 0
     for k, v in kwdict.items():
-        try:
-            a += len(v)
-        except TypeError:
-            pass
+        if k == k.lower():
+            try:
+                a += len(v)
+            except TypeError:
+                pass
     return format(a)
 
 def noarg():
@@ -607,14 +660,14 @@ def noarg():
             finally:
                 sys.path.pop(0)
 
-            fmt3 = formatter.parse("\fM " + path + ":gentext")
-            fmt4 = formatter.parse("\fM " + path + ":lengths")
+            fmt3 = formatter.parse(f"\fM {path}:gentext")
+            fmt4 = formatter.parse(f"\fM {path}:lengths")
 
         self.assertEqual(fmt1.format_map(self.kwdict), "'Title' by Name")
-        self.assertEqual(fmt2.format_map(self.kwdict), "168")
+        self.assertEqual(fmt2.format_map(self.kwdict), "139")
 
         self.assertEqual(fmt3.format_map(self.kwdict), "'Title' by Name")
-        self.assertEqual(fmt4.format_map(self.kwdict), "168")
+        self.assertEqual(fmt4.format_map(self.kwdict), "139")
 
         with self.assertRaises(TypeError):
             self.assertEqual(fmt0.format_map(self.kwdict), "")
